==> hadoop-2.10.2-src.tar.gz: hadoop-2.10.2-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-router/src/main/java/org/apache/hadoop/yarn/server/router/webapp/NavBlock.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.yarn.server.router.webapp;

import org.apache.hadoop.yarn.webapp.view.HtmlBlock;

/**
 * Navigation block for the Router Web UI.
 */
public class NavBlock extends HtmlBlock {

  @Override
  public void render(Block html) {
    html.
      div("#nav").
        h3("Cluster").
        ul().
          li().a(url(""), "About")._().
          li().a(url("federation"), "Federation")._().
          li().a(url("nodes"), "Nodes")._().
          li().a(url("apps"), "Applications")._().
      _().
      h3("Tools").
      ul().
        li().a("/conf", "Configuration")._().
        li().a("/logs", "Local logs")._().
        li().a("/stacks", "Server stacks")._().
        li().a("/jmx?qry=Hadoop:*", "Server metrics")._()._()._();
  }
}

==> hadoop-3.3.5-src.tar.gz: hadoop-3.3.5-src/hadoop-yarn-project/hadoop-yarn/hadoop-yarn-server/hadoop-yarn-server-router/src/main/java/org/apache/hadoop/yarn/server/router/webapp/NavBlock.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.hadoop.yarn.server.router.webapp;

import org.apache.hadoop.yarn.webapp.view.HtmlBlock;

/**
 * Navigation block for the Router Web UI.
 */
public class NavBlock extends HtmlBlock {

  @Override
  public void render(Block html) {
    html.
      div("#nav").
        h3("Cluster").
        ul().
          li().a(url(""), "About").__().
          li().a(url("federation"), "Federation").__().
          li().a(url("nodes"), "Nodes").__().
          li().a(url("apps"), "Applications").__().
      __().
      h3("Tools").
      ul().
        li().a("/conf", "Configuration").__().
        li().a("/logs", "Local logs").__().
        li().a("/stacks", "Server stacks").__().
        li().a("/jmx?qry=Hadoop:*", "Server metrics").__().__().__();
  }
}
